==> haskell-utility-ht-0.0.11-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-utility-ht.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utility-ht
version: 0.0.11
id: utility-ht-0.0.11-BVpr5tWJXMj5StSkdnqVlq
key: utility-ht-0.0.11-BVpr5tWJXMj5StSkdnqVlq
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
synopsis: Various small helper functions for Lists, Maybes, Tuples, Functions
description:
    Various small helper functions for Lists, Maybes, Tuples, Functions.
    Some of these functions are improved implementations of standard functions.
    They have the same name as their standard counterparts.
    Others are equivalent to functions from the @base@ package,
    but if you import them from this utility package
    then you can write code that runs on older GHC versions
    or other compilers like Hugs and JHC.
    .
    All modules are plain Haskell 98.
    The package depends exclusively on the @base@ package
    and only that portions of @base@ that are simple to port.
    Thus you do not risk a dependency avalanche by importing it.
    However, further splitting the base package might invalidate this statement.
    .
    Alternative packages: @Useful@, @MissingH@
category: Data, List
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Bool.HT Data.Eq.HT Data.Function.HT Data.Ix.Enum Data.List.HT
    Data.List.Key Data.List.Match Data.Maybe.HT Data.Monoid.HT
    Data.Ord.HT Data.Record.HT Data.String.HT Data.Tuple.HT
    Data.Tuple.Lazy Data.Tuple.Strict Control.Monad.HT
    Control.Functor.HT Data.Strictness.HT Text.Read.HT Text.Show.HT
hidden-modules: Data.Bool.HT.Private Data.List.HT.Private
                Data.List.Key.Private Data.List.Match.Private
                Data.Function.HT.Private Data.Record.HT.Private Data.Tuple.Example
abi: d903b00ca6588233a98c2da37c277e4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/utility-ht-0.0.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/utility-ht-0.0.11
data-dir: /usr/share/arm-linux-ghc-8.0.1/utility-ht-0.0.11
hs-libraries: HSutility-ht-0.0.11-BVpr5tWJXMj5StSkdnqVlq
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-utility-ht/html/utility-ht.haddock
haddock-html: /usr/share/doc/haskell-utility-ht/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utility-ht-0.0.12-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-utility-ht.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utility-ht
version: 0.0.12
id: utility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
key: utility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
stability: Stable
synopsis: Various small helper functions for Lists, Maybes, Tuples, Functions
description:
    Various small helper functions for Lists, Maybes, Tuples, Functions.
    Some of these functions are improved implementations of standard functions.
    They have the same name as their standard counterparts.
    Others are equivalent to functions from the @base@ package,
    but if you import them from this utility package
    then you can write code that runs on older GHC versions
    or other compilers like Hugs and JHC.
    .
    All modules are plain Haskell 98.
    The package depends exclusively on the @base@ package
    and only that portions of @base@ that are simple to port.
    Thus you do not risk a dependency avalanche by importing it.
    However, further splitting the base package might invalidate this statement.
    .
    Alternative packages: @Useful@, @MissingH@
category: Data, List
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Bits.HT Data.Bool.HT Data.Eq.HT Data.Function.HT Data.Ix.Enum
    Data.List.HT Data.List.Key Data.List.Match
    Data.List.Reverse.StrictElement Data.List.Reverse.StrictSpine
    Data.Maybe.HT Data.Monoid.HT Data.Ord.HT Data.Record.HT
    Data.String.HT Data.Tuple.HT Data.Tuple.Lazy Data.Tuple.Strict
    Control.Monad.HT Control.Applicative.HT Control.Functor.HT
    Data.Strictness.HT Text.Read.HT Text.Show.HT
hidden-modules: Data.Bool.HT.Private Data.List.HT.Private
                Data.List.Key.Private Data.List.Match.Private
                Data.Function.HT.Private Data.Record.HT.Private Data.Tuple.Example
abi: 4b4ee3a28c59ae1bcd3d5a72f7a6a997
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/utility-ht-0.0.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/utility-ht-0.0.12
data-dir: /usr/share/arm-linux-ghc-8.0.1/utility-ht-0.0.12
hs-libraries: HSutility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-utility-ht/html/utility-ht.haddock
haddock-html: /usr/share/doc/haskell-utility-ht/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
